==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-desktop/translations/dde-desktop_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3407"/>
        <source>Icon size</source>
        <translation>Saiz ikon</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3415"/>
        <source>Auto merge</source>
        <translation>Auto gabung</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3427"/>
        <source>Auto arrange</source>
        <translation>Auto susun</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3464"/>
        <source>Corner Settings</source>
        <translation>Tetapan Bucu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3473"/>
        <location filename="../view/canvasgridview.cpp" line="3478"/>
        <source>Set Wallpaper</source>
        <translation>Tetapkan Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3476"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Kertas Dinding dan Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3655"/>
        <source>Properties</source>
        <translation>Sifat</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3455"/>
        <source>Display Settings</source>
        <translation>Tetapan Paparan</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Tiny</source>
        <translation>Sangat kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Small</source>
        <translation>Kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="42"/>
        <source>Medium</source>
        <translation>Sederhana</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="43"/>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="44"/>
        <source>Super large</source>
        <translation>Sangat besar</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Atas Meja</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="725"/>
        <source>Wallpaper Slideshow</source>
        <translation>Paparan Slaid Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="771"/>
        <source>When login</source>
        <translation>Bila daftar masuk</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When wakeup</source>
        <translation>Bila bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="825"/>
        <source>Require a password on wakeup</source>
        <translation>Perlukan kata laluan ketika bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="857"/>
        <source>Never</source>
        <translation>Tidak Sesekali</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Wait:</source>
        <translation>Tunggu:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="892"/>
        <source>Wallpaper</source>
        <translation>Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="904"/>
        <source>Screensaver</source>
        <translation>Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="969"/>
        <source>Loading wallpapers...</source>
        <translation>Memuatkan kertas dinding...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading screensavers...</source>
        <translation>Memuatkan penyelamat skrin...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1028"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Atas Meja</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1029"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1030"/>
        <source>Both</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1105"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Laksana</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="394"/>
        <location filename="../view/watermaskframe.cpp" line="395"/>
        <source>Not authorized</source>
        <translation>Tidak dibenarkan</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="405"/>
        <location filename="../view/watermaskframe.cpp" line="406"/>
        <source>In trial period</source>
        <translation>Masih dalam percubaan</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.9.orig.tar.xz: dde-file-manager-5.6.9/src/dde-desktop/translations/dde-desktop_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3451"/>
        <source>Icon size</source>
        <translation>Saiz ikon</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3460"/>
        <source>Auto merge</source>
        <translation>Auto gabung</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3472"/>
        <source>Auto arrange</source>
        <translation>Auto susun</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3511"/>
        <source>Corner Settings</source>
        <translation>Tetapan Bucu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3520"/>
        <location filename="../view/canvasgridview.cpp" line="3525"/>
        <source>Set Wallpaper</source>
        <translation>Tetapkan Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3523"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Kertas Dinding dan Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3706"/>
        <source>Properties</source>
        <translation>Sifat</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3501"/>
        <source>Display Settings</source>
        <translation>Tetapan Paparan</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Tiny</source>
        <translation>Sangat kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Small</source>
        <translation>Kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="42"/>
        <source>Medium</source>
        <translation>Sederhana</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="43"/>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="44"/>
        <source>Super large</source>
        <translation>Sangat besar</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Atas Meja</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="727"/>
        <source>Wallpaper Slideshow</source>
        <translation>Paparan Slaid Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When login</source>
        <translation>Bila daftar masuk</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="775"/>
        <source>When wakeup</source>
        <translation>Bila bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="827"/>
        <source>Require a password on wakeup</source>
        <translation>Perlukan kata laluan ketika bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Never</source>
        <translation>Tidak Sesekali</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="861"/>
        <source>Wait:</source>
        <translation>Tunggu:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="894"/>
        <source>Wallpaper</source>
        <translation>Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="906"/>
        <source>Screensaver</source>
        <translation>Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading wallpapers...</source>
        <translation>Memuatkan kertas dinding...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="973"/>
        <source>Loading screensavers...</source>
        <translation>Memuatkan penyelamat skrin...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1031"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Atas Meja</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1032"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Kunci Skrin</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1033"/>
        <source>Both</source>
        <translation>Kedua-duanya</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1108"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Laksana</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="394"/>
        <location filename="../view/watermaskframe.cpp" line="395"/>
        <source>Not authorized</source>
        <translation>Tidak dibenarkan</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="405"/>
        <location filename="../view/watermaskframe.cpp" line="406"/>
        <source>In trial period</source>
        <translation>Masih dalam percubaan</translation>
    </message>
</context>
</TS>
